.selectable[data-v-ce1bb5dc]{-webkit-user-select:text;-khtml-user-select:text;-moz-user-select:text;-ms-user-select:text;user-select:text}.background-image[data-v-ce1bb5dc]{position:absolute}.background-image .v-img__img--cover[data-v-ce1bb5dc]{object-position:50% 20%}.v-card--variant-elevated[data-v-ce1bb5dc]{box-shadow:none;border-width:1px;border-style:solid;font-size:smaller}.description-text[data-v-ce1bb5dc] div{display:-webkit-box;-webkit-line-clamp:5;line-clamp:5;-webkit-box-orient:vertical;overflow:hidden;text-overflow:ellipsis;white-space:normal;word-break:break-word}@media(max-width:1280px){.description-text[data-v-ce1bb5dc] div{-webkit-line-clamp:3;line-clamp:3}}.hiresicon{margin-top:5px;margin-right:15px;margin-left:15px;filter:invert(100%)}.hiresicondark{margin-top:5px;margin-right:15px;margin-left:15px}
